#pragma once

#include "grade_boundary_step.hpp"

namespace defaults {

/** \brief Default grade boundary rounding  */
inline constexpr GradeBoundaryRounding boundaryRounding =
    GradeBoundaryRounding::Down;

/** \brief Default grade boundary rounding  */
inline constexpr GradeBoundaryStepSize boundaryStepSize =
    GradeBoundaryStepSize::Min1_00;

/** \brief Whether to show an option to change grade boundary rounding. */
inline constexpr bool showRoundingSetting = false;

//-----------------------------------------------------------------------

/** \brief Count students with attempt nr 0 as if it were their first attempt */
inline constexpr bool countZerothAttemptAsFirstAttempt = false;

/** \brief Require passing both open and closed part to pass the exam. */
inline constexpr bool requirePassAllParts = false;

//-----------------------------------------------------------------------

/** \brief Percentage of window width of the grade tab, which is given to the
 * grade histogram. Between 0-100. */
inline constexpr int gradeTabHistogramWidthPercentage = 70;

//-----------------------------------------------------------------------

/** \brief Maximum selectable open points passing limit. */
inline constexpr double openPointsPassingLimit = 0.5;

/** \brief Starting/Default value for the open points passing limit. */
inline constexpr double openPointsStartingPassingLimit = 0.5;

//-----------------------------------------------------------------------

/** \brief Minimum settable point histogram bucket size. */
inline constexpr double minBucketSize = 0.25;
/** \brief Maximum settable point histogram bucket size. */
inline constexpr double maxBucketSize = 5.;
/** \brief Point histogram bucket size selector step size. */
inline constexpr double bucketStep = 0.25;

//-----------------------------------------------------------------------

/** \brief The factor by which the small font size is smaller than the large
 * font size. The small font size is never smaller than the default font size.*/
inline constexpr double smallFontSizeRatio = 0.5;

//-----------------------------------------------------------------------

/** \brief If less than this share of dynexite students are in the RWTHonline or
 * bonus point file, issue a warning */
inline constexpr double studentIntersectWarningThreshold = 0.5;

} // namespace defaults
