#include "points.hpp"

#include <algorithm>
#include <ranges>
#include <stdexcept>

/**
 * \brief Call std::stod, but interpret an empty string or "-" as 0.
 */
Points stringToPoints(std::string s) noexcept(false) {

    if (s.empty() || s == "-")
        return Points{0.};
    // dynexite file might use dot or comma as decimal separator
    std::ranges::replace(s, ',', '.');

    try {

        return Points{std::stod(s)};
    } catch (const std::invalid_argument &) {
        throw std::invalid_argument{"Could not convert string \"" + s +
                                    "\" to a number."};
    }
}
